@@ -3,6 +3,7 @@
 
 #define GDK_ENABLE_BROKEN
 #include "gdk.h"
+#include "gdkalias.h"
 
 /* enumerations from "gdkcursor.h" */
 GType
@@ -97,7 +98,6 @@ gdk_cursor_type_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gdkdnd.h" */
 GType
 gdk_drag_action_get_type (void)
@@ -117,7 +117,6 @@ gdk_drag_action_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_drag_protocol_get_type (void)
 {
@@ -138,7 +137,6 @@ gdk_drag_protocol_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gdkevents.h" */
 GType
 gdk_filter_return_get_type (void)
@@ -155,7 +153,6 @@ gdk_filter_return_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_event_type_get_type (void)
 {
@@ -197,13 +194,14 @@ gdk_event_type_get_type (void)
       { GDK_SCROLL, "GDK_SCROLL", "scroll" },
       { GDK_WINDOW_STATE, "GDK_WINDOW_STATE", "window-state" },
       { GDK_SETTING, "GDK_SETTING", "setting" },
+      { GDK_OWNER_CHANGE, "GDK_OWNER_CHANGE", "owner-change" },
+      { GDK_GRAB_BROKEN, "GDK_GRAB_BROKEN", "grab-broken" },
       { 0, NULL, NULL }
     };
     etype = g_enum_register_static ("GdkEventType", values);
   }
   return etype;
 }
-
 GType
 gdk_event_mask_get_type (void)
 {
@@ -238,7 +236,6 @@ gdk_event_mask_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_visibility_state_get_type (void)
 {
@@ -254,7 +251,6 @@ gdk_visibility_state_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_scroll_direction_get_type (void)
 {
@@ -271,7 +267,6 @@ gdk_scroll_direction_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_notify_type_get_type (void)
 {
@@ -290,7 +285,6 @@ gdk_notify_type_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_crossing_mode_get_type (void)
 {
@@ -306,7 +300,6 @@ gdk_crossing_mode_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_property_state_get_type (void)
 {
@@ -321,7 +314,6 @@ gdk_property_state_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_window_state_get_type (void)
 {
@@ -333,13 +325,14 @@ gdk_window_state_get_type (void)
       { GDK_WINDOW_STATE_MAXIMIZED, "GDK_WINDOW_STATE_MAXIMIZED", "maximized" },
       { GDK_WINDOW_STATE_STICKY, "GDK_WINDOW_STATE_STICKY", "sticky" },
       { GDK_WINDOW_STATE_FULLSCREEN, "GDK_WINDOW_STATE_FULLSCREEN", "fullscreen" },
+      { GDK_WINDOW_STATE_ABOVE, "GDK_WINDOW_STATE_ABOVE", "above" },
+      { GDK_WINDOW_STATE_BELOW, "GDK_WINDOW_STATE_BELOW", "below" },
       { 0, NULL, NULL }
     };
     etype = g_flags_register_static ("GdkWindowState", values);
   }
   return etype;
 }
-
 GType
 gdk_setting_action_get_type (void)
 {
@@ -355,7 +348,21 @@ gdk_setting_action_get_type (void)
   }
   return etype;
 }
-
+GType
+gdk_owner_change_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { GDK_OWNER_CHANGE_NEW_OWNER, "GDK_OWNER_CHANGE_NEW_OWNER", "new-owner" },
+      { GDK_OWNER_CHANGE_DESTROY, "GDK_OWNER_CHANGE_DESTROY", "destroy" },
+      { GDK_OWNER_CHANGE_CLOSE, "GDK_OWNER_CHANGE_CLOSE", "close" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("GdkOwnerChange", values);
+  }
+  return etype;
+}
 
 /* enumerations from "gdkfont.h" */
 GType
@@ -373,7 +380,6 @@ gdk_font_type_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gdkgc.h" */
 GType
 gdk_cap_style_get_type (void)
@@ -391,7 +397,6 @@ gdk_cap_style_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_fill_get_type (void)
 {
@@ -408,7 +413,6 @@ gdk_fill_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_function_get_type (void)
 {
@@ -437,7 +441,6 @@ gdk_function_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_join_style_get_type (void)
 {
@@ -453,7 +456,6 @@ gdk_join_style_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_line_style_get_type (void)
 {
@@ -469,7 +471,6 @@ gdk_line_style_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_subwindow_mode_get_type (void)
 {
@@ -484,7 +485,6 @@ gdk_subwindow_mode_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_gc_values_mask_get_type (void)
 {
@@ -516,7 +516,6 @@ gdk_gc_values_mask_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gdkimage.h" */
 GType
 gdk_image_type_get_type (void)
@@ -534,7 +533,6 @@ gdk_image_type_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gdkinput.h" */
 GType
 gdk_extension_mode_get_type (void)
@@ -551,7 +549,6 @@ gdk_extension_mode_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_input_source_get_type (void)
 {
@@ -568,7 +565,6 @@ gdk_input_source_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_input_mode_get_type (void)
 {
@@ -584,7 +580,6 @@ gdk_input_mode_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_axis_use_get_type (void)
 {
@@ -606,7 +601,6 @@ gdk_axis_use_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gdkproperty.h" */
 GType
 gdk_prop_mode_get_type (void)
@@ -624,7 +618,6 @@ gdk_prop_mode_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gdkregion.h" */
 GType
 gdk_fill_rule_get_type (void)
@@ -640,7 +633,6 @@ gdk_fill_rule_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_overlap_type_get_type (void)
 {
@@ -657,7 +649,6 @@ gdk_overlap_type_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gdkrgb.h" */
 GType
 gdk_rgb_dither_get_type (void)
@@ -675,7 +666,6 @@ gdk_rgb_dither_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gdktypes.h" */
 GType
 gdk_byte_order_get_type (void)
@@ -691,7 +681,6 @@ gdk_byte_order_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_modifier_type_get_type (void)
 {
@@ -719,7 +708,6 @@ gdk_modifier_type_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_input_condition_get_type (void)
 {
@@ -735,7 +723,6 @@ gdk_input_condition_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_status_get_type (void)
 {
@@ -753,7 +740,6 @@ gdk_status_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_grab_status_get_type (void)
 {
@@ -772,7 +758,6 @@ gdk_grab_status_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gdkvisual.h" */
 GType
 gdk_visual_type_get_type (void)
@@ -793,7 +778,6 @@ gdk_visual_type_get_type (void)
   return etype;
 }
 
-
 /* enumerations from "gdkwindow.h" */
 GType
 gdk_window_class_get_type (void)
@@ -809,7 +793,6 @@ gdk_window_class_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_window_type_get_type (void)
 {
@@ -828,7 +811,6 @@ gdk_window_type_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_window_attributes_type_get_type (void)
 {
@@ -849,7 +831,6 @@ gdk_window_attributes_type_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_window_hints_get_type (void)
 {
@@ -871,7 +852,6 @@ gdk_window_hints_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_window_type_hint_get_type (void)
 {
@@ -892,7 +872,6 @@ gdk_window_type_hint_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_wm_decoration_get_type (void)
 {
@@ -912,7 +891,6 @@ gdk_wm_decoration_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_wm_function_get_type (void)
 {
@@ -931,7 +909,6 @@ gdk_wm_function_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_gravity_get_type (void)
 {
@@ -954,7 +931,6 @@ gdk_gravity_get_type (void)
   }
   return etype;
 }
-
 GType
 gdk_window_edge_get_type (void)
 {
@@ -976,6 +952,8 @@ gdk_window_edge_get_type (void)
   return etype;
 }
 
+#define __GDK_ENUM_TYPES_C__
+#include "gdkaliasdef.c"
 
 /* Generated data ends here */
 
