@@ -24,20 +24,25 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
 
+#include <config.h>
 #include <stdio.h>
 
 #include "gdktypes.h"
 #include "gdkprivate-fb.h"
-#include "config.h"
 
 GdkWindow *_gdk_fb_pointer_grab_window, *_gdk_fb_keyboard_grab_window, *_gdk_fb_pointer_grab_confine = NULL;
 gboolean _gdk_fb_pointer_grab_owner_events;
 gboolean _gdk_fb_keyboard_grab_owner_events;
 GdkEventMask _gdk_fb_pointer_grab_events, _gdk_fb_keyboard_grab_events;
 
+GdkDisplay *_gdk_display = NULL;
+GdkScreen *_gdk_screen = NULL;
+GdkWindow *_gdk_parent_root = NULL;
+
 GdkFBWindow *gdk_root_window = NULL;
 GdkFBDisplay *gdk_display = NULL;
 GdkCursor *_gdk_fb_pointer_grab_cursor;
 GdkGC *_gdk_fb_screen_gc = NULL;
 GdkAtom _gdk_selection_property;
 GdkFBAngle _gdk_fb_screen_angle = GDK_FB_0_DEGREES;
+volatile gboolean _gdk_fb_is_active_vt = FALSE;
